/**
 * Copyright (c) 2024 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */

#pragma once
#include "display/color.h"

#define FRAME_CHAR_SIZE 8
#define FRAME_PIXEL_WIDTH 320
#define FRAME_PIXEL_HEIGHT 240
#define FRAME_WIDTH FRAME_PIXEL_WIDTH/FRAME_CHAR_SIZE
#define FRAME_HEIGHT FRAME_PIXEL_HEIGHT/FRAME_CHAR_SIZE

#define FRAME_BOTTOM_UI_HEIGHT 8

extern char_t FRAME_BUFFER[FRAME_HEIGHT * FRAME_WIDTH];
extern uint8_t FRAME_COLOR[FRAME_HEIGHT * FRAME_WIDTH];

/**
 * Initializes the frame buffer.
 */
void frameInit();

/**
 * Updates the terminal frame.
 */
void frameUpdate();

/**
 * Clears the frame buffer.
 */
void frameClear();

/**
 * Draws a UI frame.
 * 
 * @param x The x position to draw the border.
 * @param y The y position to draw the border.
 * @param width The width of the border.
 * @param height The height of the border.
 * @param color The color to draw the border.
 */
void frameBoxDraw(
  const uint16_t x,
  const uint16_t y,
  const uint16_t width,
  const uint16_t height,
  const uint8_t color
);





/**
 * Draws the paused screen.
 */
void framePausedDraw();

/**
 * Redraws the entire map area of the frame.
 */
void frameMapDraw();